==> estateplat-common-1.2.4-20190813.074659-214-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxYhYwxx.java <==
package cn.gtmap.estateplat.model.exchange.share;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/5/26
 * @description 银行业务信息
 */
@Table(name = "gx_yh_ywxx")
public class GxYhYwxx implements Serializable {
    @Id
    private String id;//主键id
    private String ywbm;//业务编码
    private String shzt;//审核状态 0:未审，1：已审，2：审核不通过
    private Date createtime;//创建时间
    private Date updatetime;//更新时间
    private String bh;//银行抵押编号
    private String shyj;//审核意见
    private String djzt;//登记状态，记录流程节点名称
    private String bdcbh;//不动产编号
    private String czr;//操作人
    private String bz;//备注
    private String spyj;//审批意见
    private String sfaj;//是否按揭
    private String sfjj;//是否加急
    private String sfhcdzzz;//是否合成电子证照
    private String sjr;//收件人
    private String sjdz;//收件地址
    private Date sjsj;//收件时间
    private String jybh;//交易编号
    private String dwdm;//单位代码
    private String yhczr;//银行操作人
    private String yjzt;//移交状态
    private String sfzzdz;//是否自助打证
    private String yhbs;//银行系统唯一标识

    public String getSfhcdzzz() {
        return sfhcdzzz;
    }

    public void setSfhcdzzz(String sfhcdzzz) {
        this.sfhcdzzz = sfhcdzzz;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYwbm() {
        return ywbm;
    }

    public void setYwbm(String ywbm) {
        this.ywbm = ywbm;
    }

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }

    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }

    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    public String getBh() {
        return bh;
    }

    public void setBh(String bh) {
        this.bh = bh;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getBdcbh() {
        return bdcbh;
    }

    public void setBdcbh(String bdcbh) {
        this.bdcbh = bdcbh;
    }

    public String getCzr() {
        return czr;
    }

    public void setCzr(String czr) {
        this.czr = czr;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSpyj() {
        return spyj;
    }

    public void setSpyj(String spyj) {
        this.spyj = spyj;
    }

    public String getSfaj() {
        return sfaj;
    }

    public void setSfaj(String sfaj) {
        this.sfaj = sfaj;
    }

    public String getSjr() {
        return sjr;
    }

    public void setSjr(String sjr) {
        this.sjr = sjr;
    }

    public String getSjdz() {
        return sjdz;
    }

    public void setSjdz(String sjdz) {
        this.sjdz = sjdz;
    }

    public Date getSjsj() {
        return sjsj;
    }

    public void setSjsj(Date sjsj) {
        this.sjsj = sjsj;
    }

    public String getJybh() {
        return jybh;
    }

    public void setJybh(String jybh) {
        this.jybh = jybh;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getYhczr() {
        return yhczr;
    }

    public void setYhczr(String yhczr) {
        this.yhczr = yhczr;
    }

    public String getSfjj() {
        return sfjj;
    }

    public void setSfjj(String sfjj) {
        this.sfjj = sfjj;
    }

    public String getYjzt() {
        return yjzt;
    }

    public void setYjzt(String yjzt) {
        this.yjzt = yjzt;
    }

    public String getSfzzdz() {
        return sfzzdz;
    }

    public void setSfzzdz(String sfzzdz) {
        this.sfzzdz = sfzzdz;
    }

    public String getYhbs() {
        return yhbs;
    }

    public void setYhbs(String yhbs) {
        this.yhbs = yhbs;
    }
}

==> estateplat-common-1.2.4-20200108.011829-241-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxYhYwxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/5/26
 * @description 银行业务信息
 */
@Table(name = "gx_yh_ywxx")
public class GxYhYwxx implements Serializable {
    @Id
    private String id;//主键id
    private String ywbm;//业务编码
    private String shzt;//审核状态 0:未审，1：已审，2：审核不通过
    private Date createtime;//创建时间
    private Date updatetime;//更新时间
    private String bh;//银行抵押编号
    private String shyj;//审核意见
    private String djzt;//登记状态，记录流程节点名称
    private String bdcbh;//不动产编号
    private String czr;//操作人
    private String bz;//备注
    private String spyj;//审批意见
    private String sfaj;//是否按揭
    private String sfjj;//是否加急
    private String sfhcdzzz;//是否合成电子证照
    private String sjr;//收件人
    private String sjdz;//收件地址
    private Date sjsj;//收件时间
    private String jybh;//交易编号
    private String dwdm;//单位代码
    private String yhczr;//银行操作人
    private String yjzt;//移交状态
    private String sfzzdz;//是否自助打证
    private String yhbs;//银行系统唯一标识
    private String lqr;//领取人
    private String lqsj;//领取时间

    public String getSfhcdzzz() {
        return sfhcdzzz;
    }

    public void setSfhcdzzz(String sfhcdzzz) {
        this.sfhcdzzz = sfhcdzzz;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYwbm() {
        return ywbm;
    }

    public void setYwbm(String ywbm) {
        this.ywbm = ywbm;
    }

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }

    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }

    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    public String getBh() {
        return bh;
    }

    public void setBh(String bh) {
        this.bh = bh;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getBdcbh() {
        return bdcbh;
    }

    public void setBdcbh(String bdcbh) {
        this.bdcbh = bdcbh;
    }

    public String getCzr() {
        return czr;
    }

    public void setCzr(String czr) {
        this.czr = czr;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSpyj() {
        return spyj;
    }

    public void setSpyj(String spyj) {
        this.spyj = spyj;
    }

    public String getSfaj() {
        return sfaj;
    }

    public void setSfaj(String sfaj) {
        this.sfaj = sfaj;
    }

    public String getSjr() {
        return sjr;
    }

    public void setSjr(String sjr) {
        this.sjr = sjr;
    }

    public String getSjdz() {
        return sjdz;
    }

    public void setSjdz(String sjdz) {
        this.sjdz = sjdz;
    }

    public Date getSjsj() {
        return sjsj;
    }

    public void setSjsj(Date sjsj) {
        this.sjsj = sjsj;
    }

    public String getJybh() {
        return jybh;
    }

    public void setJybh(String jybh) {
        this.jybh = jybh;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getYhczr() {
        return yhczr;
    }

    public void setYhczr(String yhczr) {
        this.yhczr = yhczr;
    }

    public String getSfjj() {
        return sfjj;
    }

    public void setSfjj(String sfjj) {
        this.sfjj = sfjj;
    }

    public String getYjzt() {
        return yjzt;
    }

    public void setYjzt(String yjzt) {
        this.yjzt = yjzt;
    }

    public String getSfzzdz() {
        return sfzzdz;
    }

    public void setSfzzdz(String sfzzdz) {
        this.sfzzdz = sfzzdz;
    }

    public String getYhbs() {
        return yhbs;
    }

    public void setYhbs(String yhbs) {
        this.yhbs = yhbs;
    }

    public String getLqr() {
        return lqr;
    }

    public void setLqr(String lqr) {
        this.lqr = lqr;
    }

    public String getLqsj() {
        return lqsj;
    }

    public void setLqsj(String lqsj) {
        this.lqsj = lqsj;
    }
}
